@@ -22,6 +22,7 @@ import seqdb
 
 _DB = seqdb.get()
 
+
 def get_mnemonic(direction, prefix, p, i, f):
 
     params = p.split(";")
@@ -31,13 +32,13 @@ def get_mnemonic(direction, prefix, p, i, f):
     else:
         key = '%s CSI %s%s%s' % (direction, p, i, f)
         if key in _DB:
-            return _DB[key] 
+            return _DB[key]
         length = len(params)
 
 #    if length > 0:
 #        key = '%s CSI %s;[*]%s%s' % (direction, params[0], i, f)
 #        if key in _DB:
-#            return _DB[key] 
+#            return _DB[key]
 
     key = '%s CSI %s[%d]%s%s' % (direction, prefix, length, i, f)
     if key in _DB:
@@ -50,13 +51,14 @@ def get_mnemonic(direction, prefix, p, i, f):
         for x in xrange(0, length):
             key = '%s CSI %s;[%d]%s%s' % (direction, ";".join(params[:x]), length - x, i, f)
             if key in _DB:
-                return _DB[key] % tuple(params[x:]) 
+                return _DB[key] % tuple(params[x:])
 
     key = '%s CSI %s%s%s' % (direction, prefix, i, f)
     if key in _DB:
-        return _DB[key] 
+        return _DB[key]
     return '<Unknown>'
- 
+
+
 def format(parameter, intermediate, final, is_input, tracer, controller):
     p = ''.join([chr(c) for c in parameter])
     i = ''.join([chr(c) for c in intermediate]).replace(" ", "<SP>")
@@ -75,7 +77,7 @@ def format(parameter, intermediate, final, is_input, tracer, controller):
     mnemonic = get_mnemonic(direction, prefix, p, i, f)
     if mnemonic[0] == "!":
         return eval(mnemonic[1:])
-   
+
     context = []
     if p:
         context.append("\x1b[35m" + p)
@@ -84,11 +86,11 @@ def format(parameter, intermediate, final, is_input, tracer, controller):
     if f:
         context.append("\x1b[33m" + f)
 
-    result = "\x1b[0;1;31;40m CSI %s \x1b[0;1;36m\x0d\x1b[30C%s" % (" ".join(context), mnemonic)
+    template = "\x1b[0;1;31;40m CSI %s \x1b[0;1;36m\x0d\x1b[30C%s"
+    result = template % (" ".join(context), mnemonic)
     return result
 
- 
-if __name__ == "__main__":
-   import doctest
-   doctest.testmod()
 
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
