@@ -22,6 +22,7 @@ import seqdb
 
 _DB = seqdb.get()
 
+
 def get_mnemonic(p, v, is_input):
 
     if is_input:
@@ -38,19 +39,28 @@ def get_mnemonic(p, v, is_input):
         if key in _DB:
             return _DB[key]
     else:
-        params = v.split(";") 
+        params = v.split(";")
         length = len(params)
 
         if length > 3:
-            key = "%s ESC %s%s;%s;%s;%s<ST>" % (direction, p, params[0], params[1], params[2], params[3])
+            key = "%s ESC %s%s;%s;%s;%s<ST>" % (direction, p,
+                                                params[0],
+                                                params[1],
+                                                params[2],
+                                                params[3])
             if key in _DB:
                 return _DB[key]
         if length > 2:
-            key = "%s ESC %s%s;%s;%s<ST>" % (direction, p, params[0], params[1], params[2])
+            key = "%s ESC %s%s;%s;%s<ST>" % (direction, p,
+                                             params[0],
+                                             params[1],
+                                             params[2])
             if key in _DB:
                 return _DB[key]
         if length > 1:
-            key = "%s ESC %s%s;%s<ST>" % (direction, p, params[0], params[1])
+            key = "%s ESC %s%s;%s<ST>" % (direction, p,
+                                          params[0],
+                                          params[1])
             if key in _DB:
                 return _DB[key]
         if length > 0:
@@ -64,9 +74,10 @@ def get_mnemonic(p, v, is_input):
 
     return '[ESC ' + p + ']'
 
+
 def format(prefix, value, is_input, tracer, controller):
     """
-      >>> _create_mock_db() 
+      >>> _create_mock_db()
       >>> format(ord("]"), map(ord, "abcde"), False, None, None).replace("\x1b", "\\x1b")
       u'\\x1b[0;1;37;44mESC ] \\x1b[0;1;35mabcde \\x1b[37;44mST\\x1b[0;1;36m  OSC / operating system command'
 
@@ -76,7 +87,7 @@ def format(prefix, value, is_input, tracer, controller):
 
     try:
         v = u''.join(map(unichr, value))
-    except OverflowError, e:
+    except OverflowError:
         v = str(value)
     p = chr(prefix)
 
@@ -84,21 +95,22 @@ def format(prefix, value, is_input, tracer, controller):
     if mnemonic[0] == "!":
         return eval(mnemonic[1:])
 
-    result = "\x1b[0;1;37;44mESC %s \x1b[0;1;35m%s \x1b[37;44mST\x1b[0;1;36m  %s" % (p, v, mnemonic)
-    return result 
+    template = "\x1b[0;1;37;44mESC %s \x1b[0;1;35m%s \x1b[37;44mST\x1b[0;1;36m  %s"
+    result = template % (p, v, mnemonic)
+    return result
+
 
 def _create_mock_db():
     global _DB
     _DB = {
-        '> ESC ]<ST>'        : 'OSC / operating system command',
-        '> ESC ]0<ST>'       : 'OSC 0 / set icon name and window title',
-        '> ESC ]1<ST>'       : 'OSC 1 / set icon name',
-        '> ESC ]2<ST>'       : 'OSC 2 / set window title',
-        '> ESC ]4<ST>'       : 'OSC 4 / get or set color palette',
-        '> ESC ]9<ST>'       : 'OSC 9 / Growl integration (iTerm2)',
+        '> ESC ]<ST>': 'OSC / operating system command',
+        '> ESC ]0<ST>': 'OSC 0 / set icon name and window title',
+        '> ESC ]1<ST>': 'OSC 1 / set icon name',
+        '> ESC ]2<ST>': 'OSC 2 / set window title',
+        '> ESC ]4<ST>': 'OSC 4 / get or set color palette',
+        '> ESC ]9<ST>': 'OSC 9 / Growl integration (iTerm2)',
     }
- 
-if __name__ == "__main__":
-   import doctest
-   doctest.testmod()
 
+if __name__ == "__main__":
+    import doctest
+    doctest.testmod()
