@@ -18,11 +18,5 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
 
-# terminal filter framework
-__author__  = "Hayaki Saito (user@zuse.jp)"
-__version__ = "0.0.15"
-__license__ = "GPL v3"
-
-from interface import *
-from io import *
+from tff import *
 
